<?php

namespace FiloBlu\Kpi\Model;

use FiloBlu\Kpi\Helper\Data;
use Magento\Catalog\Api\ProductRepositoryInterface;
use Magento\Catalog\Model\ResourceModel\Product\Action;
use Magento\ConfigurableProduct\Model\ResourceModel\Product\Type\Configurable;
use Magento\Customer\Model\ResourceModel\Customer\CollectionFactory;
use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Framework\App\ResourceConnection;
use Magento\Framework\DB\Adapter\AdapterInterface;
use Magento\Framework\Filesystem;
use Magento\Framework\Image\AdapterFactory;
use Magento\Framework\Serialize\SerializerInterface;
use Magento\Store\Model\StoreManagerInterface;

use function count;

/**
 * Class Core
 * @package FiloBlu\Kpi\Model
 */
class Core
{
    /**
     * @var \Magento\Catalog\Model\ResourceModel\Product\CollectionFactory
     */
    protected $productCollection;
    /**
     * @var ScopeConfigInterface
     */
    protected $scopeConfig;
    /**
     * @var SerializerInterface
     */
    protected $serializer;
    /**
     * @var ResourceConnection
     */
    protected $resource;
    /**
     * @var CollectionFactory
     */
    protected $customerFactory;

    /**
     * @var ProductRepositoryInterface
     */
    protected $productRepository;

    /**
     * @var Configurable
     */
    protected $productConfigurable;
    /**
     * @var Filesystem
     */
    protected $filesystem;
    /**
     * @var AdapterFactory
     */
    protected $adapterFactory;
    /**
     * @var StoreManagerInterface
     */
    protected $storeManager;
    /**
     * @var Action
     */
    protected $productAction;

    /**
     * @var \Magento\Framework\DB\Adapter\AdapterInterface|null
     */
    protected $connection;

    /**
     * @var Data
     */
    protected $helper;

    /**
     * Core constructor.
     * @param \Magento\Catalog\Model\ResourceModel\Product\CollectionFactory $productCollection
     * @param ScopeConfigInterface $scopeConfig
     * @param SerializerInterface $serializer
     * @param ResourceConnection $resource
     * @param CollectionFactory $customerFactory
     * @param ProductRepositoryInterface $productRepositoryInterface
     * @param Data $helper
     * @param Configurable $productConfigurable
     * @param Filesystem $filesystem
     * @param AdapterFactory $adapterFactory
     * @param StoreManagerInterface $storeManagerInterface
     * @param Action $productAction
     */
    public function __construct(
        \Magento\Catalog\Model\ResourceModel\Product\CollectionFactory $productCollection,
        ScopeConfigInterface $scopeConfig,
        SerializerInterface $serializer,
        ResourceConnection $resource,
        CollectionFactory $customerFactory,
        ProductRepositoryInterface $productRepositoryInterface,
        Data $helper,
        Configurable $productConfigurable,
        Filesystem $filesystem,
        AdapterFactory $adapterFactory,
        StoreManagerInterface $storeManagerInterface,
        Action $productAction
    ) {
        $this->productCollection = $productCollection;
        $this->scopeConfig = $scopeConfig;
        $this->serializer = $serializer;
        $this->resource = $resource;
        $this->customerFactory = $customerFactory;
        $this->productRepository = $productRepositoryInterface;
        $this->helper = $helper;
        $this->productConfigurable = $productConfigurable;
        $this->filesystem = $filesystem;
        $this->adapterFactory = $adapterFactory;
        $this->storeManager = $storeManagerInterface;
        $this->productAction = $productAction;
    }

    /**
     * @return AdapterInterface
     */
    protected function getConnection()
    {
        if (!$this->connection) {
            $this->connection = $this->resource->getConnection();
        }
        return $this->connection;
    }

    /**
     * @return mixed
     */
    protected function getCustomerCollection()
    {
        return $this->customerFactory->create();
    }

    /**
     * @return mixed
     */
    protected function getProductsCollection()
    {
        return $this->productCollection->create();
    }

    /**
     * @param bool $getOnlyFirst
     * @return array|mixed
     */
    protected function getDefaultStoreIds($getOnlyFirst = false)
    {
        $result = [];
        $fallbackToStoreId = 1;

        $affectedStores = trim((string)$this->scopeConfig->getValue('kpi/table_configuration/affectedstores'));

        // Fallback store ID 1
        if (!$affectedStores) {
            if ($getOnlyFirst) {
                return $fallbackToStoreId;
            }

            $result[] = $fallbackToStoreId;
            return $result;
        }

        $storeCodes = explode(',', $affectedStores);
        $storeCodes = array_map(static function ($code) {
            return trim((string)$code);
        }, $storeCodes);

        $all_stores = $this->storeManager->getStores();

        foreach ($storeCodes as $store_code) {
            foreach ($all_stores as $store) {
                if ($store->getCode() == $store_code) {
                    $result[] = $store->getId();
                }
            }
        }

        // Fallback to default store 1 if none is found
        if (count($result) === 0) {
            $result = [];
            $result[] = $fallbackToStoreId;
        }

        if ($getOnlyFirst) {
            return $result[0];
        }

        return $result;
    }

}
